@@ -31,7 +31,7 @@ from airflow.providers.google.cloud.triggers.cloud_batch import CloudBatchJobFin
 if TYPE_CHECKING:
     from google.api_core import operation
 
-    from airflow.utils.context import Context
+    from airflow.providers.common.compat.sdk import Context
 
 
 class CloudBatchSubmitJobOperator(GoogleCloudBaseOperator):
@@ -100,19 +100,18 @@ class CloudBatchSubmitJobOperator(GoogleCloudBaseOperator):
 
             return Job.to_dict(completed_job)
 
-        else:
-            self.defer(
-                trigger=CloudBatchJobFinishedTrigger(
-                    job_name=job.name,
-                    project_id=self.project_id,
-                    gcp_conn_id=self.gcp_conn_id,
-                    impersonation_chain=self.impersonation_chain,
-                    location=self.region,
-                    polling_period_seconds=self.polling_period_seconds,
-                    timeout=self.timeout_seconds,
-                ),
-                method_name="execute_complete",
-            )
+        self.defer(
+            trigger=CloudBatchJobFinishedTrigger(
+                job_name=job.name,
+                project_id=self.project_id,
+                gcp_conn_id=self.gcp_conn_id,
+                impersonation_chain=self.impersonation_chain,
+                location=self.region,
+                polling_period_seconds=self.polling_period_seconds,
+                timeout=self.timeout_seconds,
+            ),
+            method_name="execute_complete",
+        )
 
     def execute_complete(self, context: Context, event: dict):
         job_status = event["status"]
@@ -120,8 +119,7 @@ class CloudBatchSubmitJobOperator(GoogleCloudBaseOperator):
             hook: CloudBatchHook = CloudBatchHook(self.gcp_conn_id, self.impersonation_chain)
             job = hook.get_job(job_name=event["job_name"])
             return Job.to_dict(job)
-        else:
-            raise AirflowException(f"Unexpected error in the operation: {event['message']}")
+        raise AirflowException(f"Unexpected error in the operation: {event['message']}")
 
 
 class CloudBatchDeleteJobOperator(GoogleCloudBaseOperator):
@@ -246,7 +244,7 @@ class CloudBatchListTasksOperator(GoogleCloudBaseOperator):
     :param job_name: Required. The name of the job for which to list tasks.
     :param gcp_conn_id: The connection ID used to connect to Google Cloud.
     :param filter: The filter based on which to list the jobs. If left empty, all the jobs are listed.
-    :param group_name: The name of the group that owns the task. By default it's `group0`.
+    :param group_name: The name of the group that owns the task. By default, it's `group0`.
     :param limit: The number of tasks to list.
         If left empty, all the tasks matching the filter will be returned.
     :param impersonation_chain: Optional service account to impersonate using short-term
